@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use experimental qw( isa signatures );
 
-our $VERSION = '0.014';
+our $VERSION = '0.015';
 
 use Mutex;
 use OpenTelemetry::Common;
@@ -20,6 +20,7 @@ use Sentinel;
 use Log::Any;
 
 use Exporter::Shiny qw(
+    otel_config
     otel_context_with_span
     otel_current_context
     otel_error_handler
@@ -89,6 +90,10 @@ sub _generate_otel_span_from_context {
     sub { OpenTelemetry::Trace->span_from_context(@_) };
 }
 
+sub _generate_otel_config {
+    \&OpenTelemetry::Common::config;
+}
+
 {
     my $lock = Mutex->new;
     my $instance = sub (%args) {
